@@ -18,6 +18,7 @@ import html         # for html.unescape
 import math         # for math.ceil
 import mimetypes    # for mimetypes.guesstype
 import os           # for os.path.basename
+import re           # for re.match
 import threading    # for threading.Thread
 from typing import List, Optional, Union
 
@@ -142,7 +143,7 @@ class Gmail(object):
 
         msg = self._create_message(
             sender, to, subject, msg_html, msg_plain, cc=cc, bcc=bcc,
-            attachments=attachments, signature=signature
+            attachments=attachments, signature=signature, user_id=user_id
         )
 
         try:
@@ -828,7 +829,8 @@ class Gmail(object):
         cc: List[str] = None,
         bcc: List[str] = None,
         attachments: List[str] = None,
-        signature: bool = False
+        signature: bool = False,
+        user_id: str = 'me'
     ) -> dict:
         """
         Creates the raw email message to be sent.
@@ -864,7 +866,10 @@ class Gmail(object):
             msg['Bcc'] = ', '.join(bcc)
 
         if signature:
-            account_sig = self._get_alias_info(sender, 'me')['signature']
+            m = re.match(r'.+\s<(?P<addr>.+@.+\..+)>', sender)
+            address = m.group('addr') if m else sender
+            account_sig = self._get_alias_info(address, user_id)['signature']
+
             if msg_html is None:
                 msg_html = ''
 
